C
C       combine_synoptic_snow
C
C     Program combines snow depth data from SYNOP (WMO) and US Cooperative stations in one data file
C     All file are located in the DATA subdirectory
C
C     In the data file Western Longitudes are POSITIVE
C                      Eastern Longitudes are NEGATIVE
C 
      character*7 buffer
      character*5 adate
      character*20 file_synop, file_coop, file_metar, file_combined
      character*20 file_date
      logical exst
      real lat_syn(4000), lon_syn(4000)
      real lon_all(4000), lat_all(4000)
      real lon_coop (4000), lat_coop(4000)
      dimension isnd_syn(4000), iel_syn(4000)
      dimension isnd_all(4000), iel_all(4000)
      dimension isnd_coop(4000), iel_coop(4000)
      dimension itype(4000)
      data file_synop    /'DATA/SYX._____'/
      data file_coop     /'DATA/DEP._____'/
      data file_metar    /'DATA/MET._____'/
      data file_combined /'DATA/SRF._____'/
      data file_date     /'synop_date.dat'/

      write (*,1220)
 1220 format (
     *5X,'----------------------------------------------------'/
     *5X,'|           combine_synoptic_snow                  |'/
     *5X,'|           -----------------------                |'/
     *5X,'| Combines SYNOP and US Coop snow depth reports    |'/
     *5X,'|                  in one file                     |'/
     *5X,'----------------------------------------------------')


      n_synop=0   ! number of WMO SYNOP reports
      n_coop=0   ! number of US Coop reports
      n_total=0     ! total number of snow depth reports
C
C read the date and compose file names
C 
      open (9,FILE=file_date,access='SEQUENTIAL',form='formatTED')
      read (9,'(i7)') idate
      close (9)
      write (*,'(a,i7)') 'Processing station data for date ',idate 
      iyear=idate/1000
      iday=idate-iyear*1000
      write (buffer, '(I7)') idate
      read (buffer,'(A7)') adate 
      file_synop(10:14)=adate
      file_coop(10:14)=adate
      file_metar(10:14)=adate
      file_combined(10:14)=adate
      write (*,1020) file_syn, file_coop, file_metar
 1020 format ('Will read synoptic data from files:   ', a/14x,a/14x,a)
      write (*,1430) file_combined
 1430 format ('Will save combined data in file:  ', a)
c  
c  check, if files exist
c 
        iex_synop=1
        inquire (file=file_synop,exist=exst) 
        if (.not.exst) then
          write (*,'(a)') ' No SYNOP data file found'
          iex_synop=0
        endif

        iex_metar=1
        inquire (file=file_metar,exist=exst) 
        if (.not.exst) then
          write (*,'(a)') ' No METAR data file found '
          iex_metar=0
        endif

        iex_coop=1
        inquire (file=file_coop,exist=exst) 
        if (.not.exst) then
          write (*,'(a)')' No US Coop data file found '
          iex_coop=0
        endif
        if (iex_coop.eq.0.and.iex_synop.eq.0) GO TO 50    ! NO GROUND DATA FILES FOUND
C 
C  Read SYNOP data file
C  Select reports with any snow depth reported
C 
        ipt=0
        if (iex_synop.eq.1) then    ! synop file should exist, read synop data 
          open (12,file=file_synop,form='formatted')
          do I=1,2
            read  (12,'()',end=10,err=10) 
          enddo
          write (*,'(a)')  'Getting SYNOP data'
          do I=1,3000
            read (12,1090,end=10,err=10) vlat,vlon, iday, itime, 
     *                         temp, isnow, ielev
 1090       format (f7.2,f8.2,i8,i7,f7.1,i5,11x,i7)
c            write (*,1090) vlat,vlon, iday, itime, 
c     *                         temp, isnow, ielev
            if (isnow.ge.0) then
              ipt=ipt+1    
              lat_syn(ipt)=vlat
              lon_syn(ipt)=vlon
              isnd_syn(ipt)=isnow
              iel_syn(ipt)=ielev
c              write (*,*) ipt, lat_syn(ipt),lon_syn(ipt),isnd_syn(ipt)
            endif
          enddo
          close (12)
   10     continue
        endif
c
c  Read METAR data file
c  Select reports with valid snow depth
c 
        if (iex_metar.eq.1) then
          open (12,file=file_metar, form='formatted')
          do i=1,2
            read  (12,'()',err=60,end=60) 
          enddo
          write (*,'(a)')   'Getting METAR data'
          do i=1,3000
            read (12,1390,end=60,err=60) vlat, vlon, iday, itime, 
     *                         temp, isnow, ielev
 1390       format (F7.2,F8.2,I8,I7,F7.1,I5,I7)
            if (isnow.ge.0) then
              ipt=ipt+1    
              lat_syn(ipt)=vlat
              lon_syn(ipt)=vlon
              isnd_syn(ipt)=isnow
              iel_syn(ipt)=ielev
c              write (*,*) ipt, lat_syn(ipt),lon_syn(ipt),isnd_syn(ipt)
            endif
          enddo
          close (12)
   60     continue
        endif
c
c reports from some stations may appear both in 
c SYNOP and METAR datasets. Eliminate duplicate records
c 
c Many stations report snow depth several times a day
c We select the maximum snow depth reported during the day
c 
        npt=ipt
        if (ipt.ne.0) then 
          nst=1
          lon_all(1)=lon_syn(1)    ! longitude
          lat_all(1)=lat_syn(1)    ! latitude
          isnd_all(1)=isnd_syn(1)  ! snow depth
          iel_syn(1)=iel_syn(1)    ! elevation
          do ipt=2,npt
c            write (*,*) 'new record: ', nst, ipt, 
c     *                      lat_syn(ipt),lon_syn(ipt)
            inew=1
            do ist=1,nst
              if (lon_all(ist).eq.lon_syn(ipt).and.
     *              lat_all(ist).eq.lat_syn(ipt)) then    ! repeated observations found
c                  write (*,*) 'repeated observation ',ist, ipt,
c     *                  isnd_syn(ipt), isnd_all(ist)
                  inew=0
                  if (isnd_syn(ipt).gt.isnd_all(ist)) then
                          isnd_all(ist)=isnd_syn(ipt)
c                      write (*,*) 'has been updated'
                  else
c                      write (*,*) 'has NOT been updated'
                  endif
              endif
            enddo
            if (inew.eq.1) then
                nst=nst+1
                lon_all(nst)=lon_syn(ipt)
                lat_all(nst)=lat_syn(ipt)
                isnd_all(nst)=isnd_syn(ipt)
                iel_all(nst)=iel_syn(ipt)
c                write (*,*) nst, ipt, lat_all(nst),lon_all(nst),
c     *                                           isnd_all(nst)
            endif
          enddo
          close (12)
          n_synop=nst
          do ist=1,n_synop
             itype(ist)=1
          enddo
          write (*,1100) n_synop
 1100     format ('Number of SYNOP and METAR snow reports found: ',I5)
        endif
C
C   Read COOP stations data 
C 
        write (*,'(a)')   'Getting US COOP data'
        n_coop=0
        if (iex_coop.EQ.1) then 
          open (10,file=file_coop, form='formatted')
          do ir=1,3
            read (10,'()') 
          enddo
          ist=0
            do ir=1,2000
            read (10,1120,end=90) vlat, vlon, isdep 
 1120       format (F6.2, F8.2,I4)
            backspace (10)
            read (10,1130,err=20) isel
 1130       format (62X,I5)
            goto 30
   20       isel=0
   30       continue
            ist=ist+1
            lon_coop(ist)=vlon
            lat_coop(ist)=vlat
            isnd_coop(ist)=isdep*2.54         ! convert depth from inches to cm
            iel_coop(ist)=float(isel)*0.3048  ! convert height from feet to meters
          enddo
   90     continue
          close (10)
          n_coop=ist
          write (*,1140) n_coop
 1140     format ('Number of COOP snow reports found: ', I5)
          do ist=1,n_coop
            lat_all(ist+n_synop)=lat_coop(ist)
            lon_all(ist+n_synop)=lon_coop(ist)
            isnd_all(ist+n_synop)=isnd_coop(ist)
            iel_all(ist+n_synop)=iel_coop(ist)
            itype(ist+n_synop)=2
          enddo
        endif
        n_total=n_synop+n_coop
        write (*,1150) n_total
 1150   format ('Total snow depth reports found: ',I5)      
   50   continue 
        open (4,file=file_combined,form='formatted')
        write (4,1050) idate, n_total, n_synop ,n_coop
 1050   format (I7,3X,3I5)
        do i=1,n_total
          write (4,1060) lat_all(i),lon_all(i),isnd_all(i),
     *                   iel_all(i),itype(i)
 1060     format (2F8.2, 3I7)
        enddo
        close (4)
        write (*,'(a,1x,a)')
     *       'Station snow depth data saved in file', file_combined
      end
