      SUBROUTINE TRANS_W (OPTION,AREA,ARADIR,AL,AE,XLAT,XLON,
     &                                IFLAG,ERROR,INEW)
C
C   TRANS-- Navigation transformation from navigation codicil
C           This routine will compute either area-->earth or earth-->
C           area coordinate transformations.
C
C      for GOES-WEST over Great Plains
C      -------------------------------
C
C     3/20/95  initial version-- This routine is taken directly from
C              McIDAS-X subroutine EARTH
C   arguments:
C
C     INPUT:
C
C        option (CHAR*2)
C           AE = area to earth transformation
C           EA = earth to area transformation
C        area (I)
C           area number
C        aradir (I(64))
C           area directory (64 words) of the area we want to do
C           navigation on
C
C    INPUT or OUTPUT, depending on input argument "option":
C
C        al     (I)
C           area line coordinate
C        ae     (I)
C           area element coordinate
C        xlat   (R)
C           latitude
C        xlon   (R)
C           longitude
C        error  (I)
C           error flag
C
      IMPLICIT CHARACTER*12 (C)
      IMPLICIT REAL*8       (D)
 
      CHARACTER*2            OPTION
      CHARACTER*80           DMSG
 
      REAL             X,Y,XLAT,XLON,XDUM
 
      INTEGER AREA,ARADIR(64),ERROR,FIRST
      INTEGER AL,AE
 
      LOGICAL DBUG,DIAG
 
      COMMON/DEBUG/DBUG,DIAG
      ERROR = 0
      DMSG = ' '
C
      IF(OPTION.NE.'AE'.AND.OPTION.NE.'EA') THEN
         ERROR = 1
         CALL SDEST('(TRANS) ERROR: OPTION MUST BE EITHER AE OR EA',0)
         RETURN
      ENDIF

      IF(INEW.EQ.0) THEN
C
C        Initialize navigation information
C
         INVSET = NVSET('AREA',AREA)
         IF(INVSET.NE.0) THEN
             ERROR = INVSET
             DMSG='(TRANS) ERROR: CANNOT SET NAVIGATION FOR AREA:    '//
     *       ' NVSET ERROR = '
             WRITE(DMSG(47:50),'(I4)',IOSTAT=IOS) AREA
             WRITE(DMSG(65:68),'(I4)',IOSTAT=IOS) ERROR 
             CALL SDEST(DMSG,0)
             RETURN
         ENDIF
         IF(DBUG.OR.DIAG) THEN
             DMSG='(TRANS) NAVIGATION HAS BEEN INITIALIZED '//
     *       'VIA FUNCTION NVSET...'
             CALL SDEST(DMSG,0)
         ENDIF
      ENDIF
      IF (OPTION.EQ.'AE') THEN
         IF(DBUG) THEN
C            CALL SDEST('(TRANS)ALIN,AELE='//CFI(AL)//' '//CFI(AE),0)
         ENDIF
C
C        Calculate image coordinates from input area coordinates.
C
C        ARADIR(6) = Y-COOR of upper left line in satellite coordinates
C        ARADIR(7) = X-COOR of upper left element in satellite coordinates
C        ARADIR(12)= Y-RES, line resolution of area
C        ARADIR(13)= X-RES, element resolution of area
C
         X = FLOAT( ARADIR(6) + AL*ARADIR(12) )
         Y = FLOAT( ARADIR(7) + AE*ARADIR(13) )
         IF(DBUG) THEN
C            CALL SDEST('(TRANS)ILIN,IELE='//CFG(X)//' '//CFG(Y),0)
         ENDIF
C
C        Calculate earth coordinates from image coordinates.
C
         KSTAT=NV1SAE(X,Y,0.,XLAT,XLON,XZ)
         IF(KSTAT.NE.0) THEN
            IFLAG = -1
            ERROR = KSTAT 
C            CALL SDEST('(TRANS) ERROR FROM NV1SAE = ',ERROR)
C            CALL SDEST('        NO NAV FOR AREA = ',AREA)
            RETURN
         ELSE IF(DBUG) THEN
C           CALL SDEST('(TRANS) LAT,LON='//CFG(XLAT)//' '//CFG(XLON),0)
         ENDIF
      ELSE IF (OPTION.EQ.'EA') THEN
         IF(DBUG) THEN
            CALL SDEST('(TRANS) LAT,LON='//CFG(XLAT)//' '//CFG(XLON),0)
         ENDIF
C
C        Calculate image coordinates from earth coordinates.
C
         KSTAT=NV1EAS(XLAT,XLON,0.,X,Y,XDUM)
         IF(KSTAT.NE.0) THEN
            ERROR = KSTAT 
            IFLAG = -1
C            CALL SDEST('(TRANS) ERROR FROM NV1EAS = ',KSTAT)
C            CALL SDEST('        NO NAV FOR AREA = ',AREA)
            RETURN
         ELSE IF(DBUG) THEN
            CALL SDEST('(TRANS)ILIN,IELE='//CFG(X)//' '//CFG(Y),0)
         ENDIF
C
C        Calculate area coordinates from image coordinates.
C        
C        ARADIR(6) = Y-COOR of upper left line in satellite coordinates
C        ARADIR(7) = X-COOR of upper left element in satellite coordinates
C        ARADIR(12)= Y-RES, line resolution of area
C        ARADIR(13)= X-RES, element resolution of area
C
         AL =   NINT( ( (X - REAL(ARADIR(6))) / 
     *          REAL(ARADIR(12)) ) + 0.6)        ! 0.0 (before Sept 24, 2001)            
C                                                ! 1.0 (Sept 24, 2001 - Feb 21,2003)           -2003052
C                                                ! 0   (Feb 21, 2003 - Feb 26,2003)     2003052-2003057
C                                                ! 0.5 (Feb 26, 2003 -  March 3, 2003)  2003057-2003062
C                                                ! 0.5 (March 4, 2003 - Nov 10, 2003)      2003062-2002313
C                                                ! 0.8 (Nov 10, 2003 - Nov 12,2003 )      2003313-2003315
C                                                ! 0.6 (Nov 12, 2003 -  )      2003315-

         AE =   NINT( ( (Y - REAL(ARADIR(7))) / 
     *          REAL(ARADIR(13)) ) + 0.6)        ! 0.0 (before Sept 24, 2001)
C                                                ! 1.0 (Sept 24, 2001 - Feb 21,2003) 
C                                                ! 0   (Feb 21, 2003 - Feb 26,2003) 
C                                                ! 0.5 (Feb 26, 2003 - March 3, 2003)
C                                                ! 0.5 (March 4, 2003 -Nov 10,2003)     2003062-2003313
C                                                ! 0.6 (Nov 12, 2003- )      2003315-

         IF(DBUG) THEN
C           CALL SDEST('(TRANS)ALIN,AELE='//CFI(AL)//' '//CFI(AE),0)
         ENDIF
      ENDIF
      RETURN
      END
